0.0.10 (2021-04-07)
-------------------

### :notebook: Notes

- Testing release process


0.0.9 (2021-04-07)
------------------

### :notebook: Notes

- Testing release process


0.0.8 (2021-04-07)
------------------

### :books: Documentation

- Add CODE OF CONDUCT


0.0.7 (2021-04-07)
------------------

### :books: Documentation

- Add CONTRIBUTING guide


0.0.6 (2021-04-06)
------------------


### :books: Documentation

- Added Progress table to README


0.0.5 (2021-04-06)
------------------

### :pencil2: Changed

- Main functionality is now provided through a pytest plugin rather than a fixture

### :books: Documentation

- Update README with pytest plugin usage

0.0.4 (2021-04-05)
------------------

### :sparkles: Added

- Added Changelog
